==> PackagedAuto-1.12.2-1.0.16.59-sources.jar: thelm/packagedauto/network/packet/PacketSizedMarker.java <==
package thelm.packagedauto.network.packet;

import io.netty.buffer.ByteBuf;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.util.math.Vec3d;
import net.minecraftforge.fml.common.network.simpleimpl.IMessage;
import net.minecraftforge.fml.common.network.simpleimpl.MessageContext;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import thelm.packagedauto.client.WorldOverlayRenderer;
import thelm.packagedauto.network.ISelfHandleMessage;
import thelm.packagedauto.network.PacketHandler;

public class PacketSizedMarker implements ISelfHandleMessage<IMessage> {

	private Vec3d lowerCorner;
	private Vec3d size;
	private int color;
	private int lifetime;

	public PacketSizedMarker() {}

	public PacketSizedMarker(Vec3d lowerCorner, Vec3d size, int color, int lifetime) {
		this.lowerCorner = lowerCorner;
		this.size = size;
		this.color = color;
		this.lifetime = lifetime;
	}

	@Override
	public void toBytes(ByteBuf buf) {
		buf.writeDouble(lowerCorner.field_72450_a);
		buf.writeDouble(lowerCorner.field_72448_b);
		buf.writeDouble(lowerCorner.field_72449_c);
		buf.writeDouble(size.field_72450_a);
		buf.writeDouble(size.field_72448_b);
		buf.writeDouble(size.field_72449_c);
		buf.writeMedium(color);
		buf.writeShort(lifetime);
	}

	@Override
	public void fromBytes(ByteBuf buf) {
		lowerCorner = new Vec3d(buf.readDouble(), buf.readDouble(), buf.readDouble());
		size = new Vec3d(buf.readDouble(), buf.readDouble(), buf.readDouble());
		color = buf.readUnsignedMedium();
		lifetime = buf.readUnsignedShort();
	}

	@SideOnly(Side.CLIENT)
	@Override
	public IMessage onMessage(MessageContext ctx) {
		Minecraft.func_71410_x().func_152344_a(()->{
			WorldOverlayRenderer.INSTANCE.addSizedMarker(lowerCorner, size, color, lifetime);
		});
		return null;
	}

	public static void sendSizedMarker(EntityPlayerMP player, Vec3d lowerCorner, Vec3d size, int color, int lifetime) {
		PacketHandler.INSTANCE.sendTo(new PacketSizedMarker(lowerCorner, size, color, lifetime), player);
	}
}

==> PackagedAuto-1.12.2-1.0.20.67-sources.jar: thelm/packagedauto/network/packet/PacketSizedMarker.java <==
package thelm.packagedauto.network.packet;

import io.netty.buffer.ByteBuf;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.util.math.Vec3d;
import net.minecraftforge.fml.common.network.simpleimpl.IMessage;
import net.minecraftforge.fml.common.network.simpleimpl.MessageContext;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import thelm.packagedauto.client.WorldOverlayRenderer;
import thelm.packagedauto.network.ISelfHandleMessage;
import thelm.packagedauto.network.PacketHandler;

public class PacketSizedMarker implements ISelfHandleMessage<IMessage> {

	private Vec3d lowerCorner;
	private Vec3d size;
	private int color;
	private int lifetime;

	public PacketSizedMarker() {}

	public PacketSizedMarker(Vec3d lowerCorner, Vec3d size, int color, int lifetime) {
		this.lowerCorner = lowerCorner;
		this.size = size;
		this.color = color;
		this.lifetime = lifetime;
	}

	@Override
	public void toBytes(ByteBuf buf) {
		buf.writeDouble(lowerCorner.x);
		buf.writeDouble(lowerCorner.y);
		buf.writeDouble(lowerCorner.z);
		buf.writeDouble(size.x);
		buf.writeDouble(size.y);
		buf.writeDouble(size.z);
		buf.writeMedium(color);
		buf.writeShort(lifetime);
	}

	@Override
	public void fromBytes(ByteBuf buf) {
		lowerCorner = new Vec3d(buf.readDouble(), buf.readDouble(), buf.readDouble());
		size = new Vec3d(buf.readDouble(), buf.readDouble(), buf.readDouble());
		color = buf.readUnsignedMedium();
		lifetime = buf.readUnsignedShort();
	}

	@SideOnly(Side.CLIENT)
	@Override
	public IMessage onMessage(MessageContext ctx) {
		Minecraft.getMinecraft().addScheduledTask(()->{
			WorldOverlayRenderer.INSTANCE.addSizedMarker(lowerCorner, size, color, lifetime);
		});
		return null;
	}

	public static void sendSizedMarker(EntityPlayerMP player, Vec3d lowerCorner, Vec3d size, int color, int lifetime) {
		PacketHandler.INSTANCE.sendTo(new PacketSizedMarker(lowerCorner, size, color, lifetime), player);
	}
}
